@@ -16,6 +16,10 @@
 #[macro_use]
 extern crate tracing;
 
+#[allow(unused_imports)]
+#[macro_use]
+pub extern crate hex;
+
 // ---
 // Export the #[node] attribute macro.
 pub use ockam_node_attribute::*;
@@ -29,11 +33,14 @@ pub use ockam_node::*;
 pub use ockam_node_no_std::*;
 // ---
 
+mod delay;
 mod error;
 mod lease;
+mod monotonic;
 mod protocols;
 mod remote_forwarder;
 
+pub use delay::*;
 pub use error::*;
 pub use lease::*;
 pub use ockam_core::worker;
@@ -41,6 +48,8 @@ pub use ockam_entity::*;
 pub use protocols::*;
 pub use remote_forwarder::*;
 
+pub mod stream;
+
 pub use ockam_core::{
     Address, Any, Encoded, Error, Message, ProtocolId, Result, Route, Routed, RouterMessage,
     TransportMessage, Worker,
