@@ -1,5 +1,6 @@
 use crate::{
-    error::OckamError, protocols::ProtocolPayload, Any, Message, ProtocolId, Result, Routed, Worker,
+    error::OckamError, protocols::ProtocolPayload, Any, Context, Message, ProtocolId, Result,
+    Routed, Worker,
 };
 use std::{collections::BTreeMap, marker::PhantomData, ops::Deref, sync::Arc, sync::RwLock};
 
@@ -20,8 +21,14 @@ where
     fn ids(&self) -> Vec<ProtocolId>;
 
     /// Parse an incoming message for a particular worker
-    fn parse(&self, _state: &mut W, _msg: ProtocolPayload) -> Result<()> {
-        Ok(())
+    fn parse(
+        &self,
+        _state: &mut W,
+        _ctx: &mut Context,
+        _routed: &Routed<Any>,
+        _msg: ProtocolPayload,
+    ) -> Result<bool> {
+        Ok(false)
     }
 }
 
@@ -103,20 +110,18 @@ impl<W: Worker> ProtocolParserImpl<W> {
     ///
     /// You may want to call [`prepare()`](Self::prepare) before
     /// calling this function.
-    pub fn parse(self: Arc<Self>, w: &mut W, msg: Routed<Any>) -> Result<()> {
-        let msg = msg.into_transport_message();
-
+    pub fn parse(self: Arc<Self>, w: &mut W, ctx: &mut Context, msg: &Routed<Any>) -> Result<bool> {
         // Parse message as a ProtocolPayload to grab the ProtocolId
-        let proto_msg = ProtocolPayload::decode(&msg.payload).unwrap();
+        let proto_msg = ProtocolPayload::decode(msg.payload())?;
         let proto = ProtocolId::from_str(proto_msg.protocol.as_str());
 
-        trace!("Parsing message for '{:?}' protocol", proto.as_str());
+        trace!("Parsing message for '{}' protocol", proto.as_str());
 
         // Get the protocol specific parser
         let map = self.map.read().unwrap();
         let parser = map.get(&proto).ok_or(OckamError::NoSuchParser)?;
 
         // Finally call the parser
-        parser.parse(w, proto_msg)
+        parser.parse(w, ctx, msg, proto_msg)
     }
 }
